import { FaTimesCircle } from "react-icons/fa";
import Checkbox from "../../base/checkbox";
import "./task.css";
import {
  useEffect,
  useRef,
  useLayoutEffect,
  useState,
  useCallback,
} from "react";

function Task({ id, title, isCompleted, onDelete, onChange, onEdit }) {
  const [debouncetitle, setDebounceTitle] = useState(title);
  const [ischeck, setIsCheck] = useState(isCompleted);
  const textarea_ref = useRef(null);

  const handleDelete = (e) => {
    e.preventDefault();
    const dialog = window.confirm("Do you want to delete?");
    if (dialog) {
      onDelete({ id });
      return true;
    }
    return false;
  };
  const handleChange = useCallback(() => {
    setIsCheck(!ischeck);
    onChange({ id, isCompleted: ischeck ? true : false });
  }, [ischeck]);

  const handleContent = (e) => {
    setDebounceTitle(e.target.value);
    const textarea = document.querySelector("textarea");
    textarea.addEventListener("keyup", (e) => {
      let scheight = e.target.scrollHeight;
      textarea.style.height = `${scheight}px`;
    });
  };

  //debounce
  useEffect(() => {
    const handler = setTimeout(() => {
      if (textarea_ref.current.value != title) {
        onEdit({ id, title: debouncetitle });
      }
    }, 2000);

    return () => {
      clearTimeout(handler);
    };
  }, [debouncetitle]);

  useLayoutEffect(() => {
    const scrollHeight = textarea_ref.current.scrollHeight;
    textarea_ref.current.style.height = `${scrollHeight}px`;
  }, [debouncetitle]);
  return (
    <div className="task-section">
      <div>
        <Checkbox
          onChange={handleChange}
          checked={ischeck}
          // disabled={ischeck}
        />

        <textarea
          ref={textarea_ref}
          className={`${isCompleted ? "strike-through" : ""}`}
          contentEditable={true}
          value={debouncetitle}
          onChange={handleContent}
          disabled={isCompleted}
        ></textarea>
      </div>
      <FaTimesCircle className="fa-close" onClick={handleDelete} />
    </div>
  );
}

export default Task;
